pub struct VaultConfig {
pub ownership: Ownership,
pub seed_authority: Pubkey,
pub underlying_mint: Pubkey,
pub derivative_mint: Pubkey,
pub underlying_vault: Pubkey,
pub id: u64,
pub underlying_assets: u64,
pub derivative_decimals: u8,
pub bump: u8,
pub underlying_vault_bump: u8,
pub derivative_mint_bump: u8,
}Fields
ownership: Ownershipunderlying_mint: Pubkeyderivative_mint: Pubkeyunderlying_vault: Pubkeyid: u64underlying_assets: u64derivative_decimals: u8bump: u8underlying_vault_bump: u8derivative_mint_bump: u8Trait Implementations
Sourceimpl AccountDeserialize for VaultConfig
impl AccountDeserialize for VaultConfig
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for VaultConfig
impl AccountSerialize for VaultConfig
Sourceimpl BorshDeserialize for VaultConfigwhere
Ownership: BorshDeserialize,
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for VaultConfigwhere
Ownership: BorshDeserialize,
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for VaultConfig
impl BorshSerialize for VaultConfig
Sourceimpl Clone for VaultConfig
impl Clone for VaultConfig
Sourcefn clone(&self) -> VaultConfig
fn clone(&self) -> VaultConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Discriminator for VaultConfig
impl Discriminator for VaultConfig
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl Space for VaultConfig
impl Space for VaultConfig
const INIT_SPACE: usize